# django-kerberos - SPNEGO/Kerberos authentication for Django applications
# Copyright (C) 2014-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import logging

import gssapi
import gssapi.exceptions
import gssapi.raw as gb

logger = logging.getLogger('django_kerberos')


def check_password(principal, password):
    try:
        name = gb.import_name(principal.encode(), gb.NameType.kerberos_principal)
        if gb.acquire_cred_with_password(name, password.encode('utf-8')):
            return True
    except gssapi.exceptions.GSSError as e:
        logger.warning('kerberos password check failed %s', e)
    return False
